' OnBeforeFolderChange_OpenNewtab:
' Revision:    v1.0.1 (vb)
' (c) 2014 steje
'
' This is a script for written for Directory Opus v11.
' See http://www.gpsoft.com.au/redirect.asp?page=scripts for development information.

' =====================================================================================
' ======================   EVENT HANDLER: OnBeforeFolderChange   ======================
'
' The purpose of this script is to provide a way for users to control which specific
' folder paths Opus will open in a NEWTAB when 'opened'. I say 'opened' because it does
' not matter if a folder is opened via double-click, <Enter> key, some other use of the
' 'Go' command, or clicking on it in the folder tree.
'
' In order to trigger this script to actually do anything, after installing it, users
' must add the full folder paths which they will want opened in new tabs to the scripts
' OpenNewtabList list. This list is accessible via the scripts listing in Preferences /
' Toolbars / Scripts by clicking, on the scripts 'Configure' button.


' Called by Directory Opus to initialize the script
Function OnInit(ByRef initData)

   ' Provide basic information about the Script
   initData.name = "OnBeforeFolderChange_OpenNewtab"
   initData.desc = "Event Handler for BeforeFolderChange event to open user-defined folders in new tab..."
   initData.copyright = "(c) 2014 steje"
   initData.version = "v1.0.1 (vb)"
   initData.default_enable = True

   ' Set DEBUG flag below to true in order to enable logging messages to the Opus Output Window
   initData.config.DEBUG = False

   ' Set initial folder path to always open in a newtab
   initData.config.objOpenNewtabList = Array("")

End Function


' Called whenever the folder is being changed
Function OnBeforeFolderChange(ByRef beforeFolderChangeData)

   Dim i, x, intOpenNewtabList, strPath, strCommand
   Const vbQuote = """"

   ' Create a Command object in order to run the necessary 'Go NEWTAB' command
   Set objCmd = DOpus.CreateCommand
   objCmd.SetSourceTab(beforeFolderChangeData.tab)

   ' If we ever find a need to do some sort of conversion of the folder path the user is actually opening, do it here
   ' Might do well to try the FSUtil.Resolve method Jon added in Beta 5 here for Library and/or collection paths?
   strPath = beforeFolderChangeData.path

   ' Loop through all entries in OpenNewtabList and check the path the user is opening against them
   logMsg("")
   logMsg("User opening path:  " & strPath)
   logMsg("Checking OpenNewtabList:")
   intOpenNewtabList = UBound(Script.config.objOpenNewtabList)
   i = 0
   For Each x in (Script.config.objOpenNewtabList)
      ' If we ever find a need to do some sort of conversion of the user defined folder paths, do it here
      logMsg("  OpenNewtabList(" & i & "):  " & x)
      If ((StrComp(strPath, x, vbTextCompare)) = 0) Then
         logMsg("Match found - open new tab for:  " & strPath)
         strCommand = "Go " &  vbQuote & strPath &  vbQuote & " NEWTAB"
         objCmd.RunCommand(strCommand)
         OnBeforeFolderChange = True
         Exit For
      Else
         logMsg("    NO MATCH!")
      End If
      i = i + 1
   Next

   If (i = intOpenNewtabList + 1) Then
      logMsg("No matches found in OpenNewtabList!")
      logMsg("Exit")
   End If

   Set objCmd = Nothing

End Function


' Subroutine to allow toggling of the global DEBUG variable to control whether logging is performed or not
Sub logMsg(ByRef message)

   If (Script.config.DEBUG) Then DOpus.Output(message)

End Sub
